@@ -6,7 +6,7 @@ if test "$#" != "3" ; then
 fi
 
 STARTDIR=`pwd`
-TARGET=$1
+TARGET=`readlink -f $1`
 DEB_TARGET_GNU_CPU=$2
 DEB_TARGET_GNU_SYSTEM=$3
 
